@@ -20,6 +20,7 @@
 #include "Table.h"
 #include "utils/misc.h"
 #include "utils/text.h"
+#include "utils/richtext.h"
 #include "search.h"
 #include "update.h"
 #include "global-settings.h"
@@ -209,9 +210,10 @@ namespace {
 } // namespace
 ///////////////////////////////////////////////////////////////////
 
-void printInfo(Zypper & zypper, const std::vector<std::string> &names_r, const PrintInfoOptions &options_r )
+void printInfo( Zypper & zypper, const std::vector<std::string> &names_r, const PrintInfoOptions &options_r )
 {
   zypper.out().gap();
+  bool noMatches = true;
 
   for ( const std::string & rawarg : names_r )
   {
@@ -254,19 +256,21 @@ void printInfo(Zypper & zypper, const std::vector<std::string> &names_r, const P
       PoolQuery h( printInfo_BasicQuery( zypper, options_r ) );
       h.addAttribute( sat::SolvAttr::name, kn._name );
 
-      if ( h.empty() )
+      if ( h.empty() ) {
         continue;
-      else if ( !fallBackToAny )
-      {
+      }
+      else if ( !fallBackToAny ) {
         logOtherKindMatches( h, kn._name );
         continue;
       }
-      else
+      else {
         q = h;
+      }
     }
 
     for_( it, q.selectableBegin(), q.selectableEnd() )
     {
+      if ( noMatches ) noMatches = false;
       const ui::Selectable & sel( *(*it) );
 
       if ( zypper.out().type() != Out::TYPE_XML )
@@ -288,6 +292,13 @@ void printInfo(Zypper & zypper, const std::vector<std::string> &names_r, const P
       else 						{ printDefaultInfo( zypper, sel, options_r ); }
     }
   }
+
+  if ( noMatches ) {
+    zypper.out().info(_("No matching items found."), Out::QUIET );
+    if ( !zypper.config().ignore_unknown ) {
+      zypper.setExitInfoCode( ZYPPER_EXIT_INF_CAP_NOT_FOUND );
+    }
+  }
 }
 
 /** Information for kinds which don't have a extra needs... */
